@@ -124,7 +124,7 @@ class FakeIndirectionAPI(base.VersionedObjectIndirectionAPI):
         kwargs = dict(
             [(argname, self._ser.deserialize_entity(
                 context, self._ser.serialize_entity(context, arg)))
-             for argname, arg in six.iteritems(kwargs)])
+             for argname, arg in kwargs.items()])
         return args, kwargs
 
     def object_action(self, context, objinst, objmethod, args, kwargs):
@@ -265,8 +265,8 @@ class ObjectVersionChecker(object):
                 obj_name, extra_data_func=extra_data_func)
         return fingerprints
 
-    def test_hashes(self, expected_hashes):
-        fingerprints = self.get_hashes()
+    def test_hashes(self, expected_hashes, extra_data_func=None):
+        fingerprints = self.get_hashes(extra_data_func=extra_data_func)
 
         stored = set(expected_hashes.items())
         computed = set(fingerprints.items())
@@ -369,12 +369,13 @@ class ObjectVersionChecker(object):
             for my_version, child_version in versions:
                 _my_version = vutils.convert_version_to_tuple(my_version)
                 _ch_version = vutils.convert_version_to_tuple(child_version)
-                assert (last_my_version < _my_version
-                        and last_child_version <= _ch_version), \
-                    ('Object %s relationship '
-                     '%s->%s for field %s is out of order') % (
-                         obj_class.obj_name(), my_version,
-                         child_version, field)
+                if not (last_my_version < _my_version
+                        and last_child_version <= _ch_version):
+                    raise AssertionError(('Object %s relationship %s->%s for '
+                                          'field %s is out of order') % (
+                                              obj_class.obj_name(),
+                                              my_version, child_version,
+                                              field))
                 last_my_version = _my_version
                 last_child_version = _ch_version
 
